@@ -3,7 +3,7 @@ package WWW::PAUSE::CleanUpHomeDir;
 use warnings;
 use strict;
 
-our $VERSION = '0.004';
+our $VERSION = '1.001001'; # VERSION
 
 use Carp;
 use URI;
@@ -12,8 +12,8 @@ use HTML::TokeParser::Simple;
 use File::Basename;
 use Devel::TakeHashArgs;
 use Sort::Versions;
-use base 'Class::Data::Accessor';
-__PACKAGE__->mk_classaccessors (qw(
+use base 'Class::Accessor::Grouped';
+__PACKAGE__->mk_group_accessors(simple => qw(
     error
     last_list
     deleted_list
@@ -103,18 +103,26 @@ sub list_old {
                         and $list_ref->{$_}{status} !~ /$scheduled_re/
                     } keys %$list_ref;
 
-    my @files = sort { 
+    my @files = sort {
         my ($na, $va) = $a =~ /(.+)-(\d.+)/;
         my ($nb, $vb) = $b =~ /(.+)-(\d.+)/;
-        $na cmp $nb || versioncmp($va, $vb); 
-    } keys %files;
+        $na cmp $nb || versioncmp($va, $vb);
+    } grep !/
+        -(?!.*-)  # last dash in the filename
+        .*(TRIAL|_) # trial versions
+    /x, keys %files;
+
     my @old;
     my $re = qr/([^.]+)-/;
     for ( 0 .. $#files-1) {
         my $name      = ($files[ $_   ] =~ /$re/)[0];
         my $next_name = ($files[ $_+1 ] =~ /$re/)[0];
         next
-            unless defined $name and defined $next_name;
+            unless ( defined $name and defined $next_name )
+                or $next_name =~ /
+                    -(?!.*-)  # last dash in the filename
+                    .*(TRIAL|_) # trial versions
+                /x;
 
         push @old, $files[$_]
             if $name eq $next_name;
@@ -260,18 +268,22 @@ __END__
 
 =encoding utf8
 
+=for stopwords AnnoCPAN Haryanto Mengu Mengué RT SHARYANTO dists occured undeletion versioning dir
+
 =head1 NAME
 
 WWW::PAUSE::CleanUpHomeDir - the module to clean up old dists from your PAUSE home directory
 
 =head1 SYNOPSIS
 
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-code.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
     use strict;
     use warnings;
 
     use WWW::PAUSE::CleanUpHomeDir;
 
-    my $pause = WWW::PAUSE::CleanUpHomeDir->new( 'PAUSE_ID', PASSWORD' );
+    my $pause = WWW::PAUSE::CleanUpHomeDir->new( 'PAUSE_ID', 'PASSWORD' );
 
     $pause->fetch_list
         or die $pause->error;
@@ -304,6 +316,8 @@ WWW::PAUSE::CleanUpHomeDir - the module to clean up old dists from your PAUSE ho
 
     print "Success..\n";
 
+=for html  </div></div>
+
 =head1 DESCRIPTION
 
 The module provides means to clean up your PAUSE home directory from
@@ -345,7 +359,7 @@ B<Optional>. As of version 0.003, this module will use HTTPS protocol
 when dealing with PAUSE. If you want to go back to using plain HTTP,
 set C<use_http> argument to a true value. B<By default:> not specified
 (i.e. will use HTTPS).
-    
+
 =head3 C<timeout>
 
     my $pause = WWW::PAUSE::CleanUpHomeDir->new(
@@ -393,7 +407,7 @@ file is scheduled for deletion.
 
     my $last_list_ref = $pause->last_list;
 
-Must be called after a successfull call to C<fetch_list()> method.
+Must be called after a successful call to C<fetch_list()> method.
 Takes no arguments, returns the same hashref as last call to C<fetch_list()>
 returned.
 
@@ -462,7 +476,7 @@ the call will cause L<WWW::Mechanize> to croak on you.
 
     my $last_deleted_files_ref = $pause->deleted_list;
 
-Must be called after a successfull call to C<clean_up()>.
+Must be called after a successful call to C<clean_up()>.
 Takes no arguments, returns the same return value last call to C<clean_up()>
 returned.
 
@@ -480,7 +494,7 @@ reason for failure will be available via C<error()> method. On success
 returns an arrayref of files which were undeleted. Takes one optional
 argument which must be an arrayref of files to undelete, if the argument
 is not specified will use list stored in C<deleted_list()>.
-B<Note:> a successfull call to this method will reset list stored in
+B<Note:> a successful call to this method will reset list stored in
 C<deleted_list()>
 but will B<NOT> reset list stored in C<last_list()>, which will be incorrect
 after undeletion (well, only the C<status> keys will present incorrect
@@ -493,7 +507,7 @@ B<Note 2:> if either the file you specified does no exist
 
     my $last_error = $pause->error;
 
-Takes no arguments, returns last error (if any) which occured during
+Takes no arguments, returns last error (if any) which occurred during
 the calls to other methods.
 
 =head1 EXAMPLES
@@ -505,7 +519,46 @@ can be used for cleaning up your PAUSE home directory.
 
 L<http://pause.perl.org>
 
-=head1 BUG REPORTS AND CONTRIBUTIONS
+=for html <div style="background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/hr.png);height: 18px;"></div>
+
+=head1 REPOSITORY
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/WWW-PAUSE-CleanUpHomeDir>
+
+=for html  </div></div>
+
+=head1 BUGS AND CAVEATS
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-bugs.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+I have only one PAUSE account which is inadequate for proper testing.
+Double check the results to make sure the module works properly for you
+when first using it.
+
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/WWW-PAUSE-CleanUpHomeDir/issues>
+
+If you can't access GitHub, you can email your request
+to C<bug-www-pause-cleanuphomedir at rt.cpan.org>
+
+=for html  </div></div>
+
+=head1 AUTHOR
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-author.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
+
+=for text Zoffix Znet <zoffix at cpan.org>
+
+=for html  </div></div>
+
+=head1 CONTRIBUTORS
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-contributors.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
 =over 4
 
@@ -515,54 +568,12 @@ L<http://pause.perl.org>
 
 =back
 
-=head1 AUTHOR
+=for html  </div></div>
 
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+=head1 LICENSE
 
-=head1 BUGS AND CAVEATS
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
-I have only one PAUSE account which is inadequate for proper testing.
-Double check the results to make sure the module works properly for you
-when first using it.
-
-Please report any bugs or feature requests to C<bug-www-pause-cleanuphomedir at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-PAUSE-CleanUpHomeDir>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc WWW::PAUSE::CleanUpHomeDir
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-PAUSE-CleanUpHomeDir>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/WWW-PAUSE-CleanUpHomeDir>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/WWW-PAUSE-CleanUpHomeDir>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/WWW-PAUSE-CleanUpHomeDir>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-=cut
+=cut
\ No newline at end of file
